==> apache-geode-benchmarks-1.13.8-src.tgz: apache-geode-benchmarks-1.13.8-src/harness/src/test/java/org/apache/geode/perftest/jvms/RemoteJVMFactoryIntegrationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.geode.perftest.jvms;

import static org.junit.jupiter.api.Assertions.assertTrue;

import java.io.File;
import java.nio.file.Path;
import java.util.Collections;
import java.util.Map;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.junitpioneer.jupiter.TempDirectory;

import org.apache.geode.perftest.infrastructure.local.LocalInfrastructureFactory;

@ExtendWith(TempDirectory.class)
public class RemoteJVMFactoryIntegrationTest {


  Path temporaryFolder;

  @BeforeEach
  void createTemporaryFolder(@TempDirectory.TempDir Path temporaryFolder) {
    this.temporaryFolder = temporaryFolder;
  }

  @Test
  public void canExecuteCodeOnWorker() throws Exception {
    RemoteJVMFactory remoteJvmFactory = new RemoteJVMFactory(new LocalInfrastructureFactory());
    Map<String, Integer> roles = Collections.singletonMap("worker", 1);
    try (RemoteJVMs jvms = remoteJvmFactory.launch(roles, Collections.emptyMap())) {
      File tempFile = temporaryFolder.resolve("tmpfile").toFile();
      jvms.execute(context -> {
        tempFile.createNewFile();
      }, "worker");

      assertTrue(tempFile.exists());
    }
  }

}

==> apache-geode-benchmarks-1.15.2-src.tgz: apache-geode-benchmarks-1.15.2-src/harness/src/test/java/org/apache/geode/perftest/jvms/RemoteJVMFactoryIntegrationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.geode.perftest.jvms;

import static org.junit.jupiter.api.Assertions.assertTrue;

import java.io.File;
import java.nio.file.Path;
import java.util.Collections;
import java.util.Map;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.io.TempDir;

import org.apache.geode.perftest.infrastructure.local.LocalInfrastructureFactory;

public class RemoteJVMFactoryIntegrationTest {

  @TempDir
  Path temporaryFolder;

  @Test
  public void canExecuteCodeOnWorker() throws Exception {
    RemoteJVMFactory remoteJvmFactory = new RemoteJVMFactory(new LocalInfrastructureFactory());
    Map<String, Integer> roles = Collections.singletonMap("worker", 1);
    try (RemoteJVMs jvms = remoteJvmFactory.launch(roles, Collections.emptyMap())) {
      File tempFile = temporaryFolder.resolve("tmpfile").toFile();
      jvms.execute(context -> {
        tempFile.createNewFile();
      }, "worker");

      assertTrue(tempFile.exists());
    }
  }

}
